/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jetspeed.util.interceptors;

import org.aopalliance.intercept.MethodInterceptor;
import org.aopalliance.intercept.MethodInvocation;
import org.apache.jetspeed.page.impl.DatabasePageManagerCache;

/**
 * Aspect that will attempt to rollback cache entries upon Page Manager failures
 *
 * @author <a href="mailto:david@bluesunrise.com">David Sean Taylor</a>
 */
public class PageManagerInterceptor implements MethodInterceptor
{

    /** Serialization version identifier */
    private static final long serialVersionUID = -1316279974504594833L;

    /**
     * Encloses <code>super.invoke()</code> in a try/catch block, where the
     * catch block contains additional retry logic.
     */
    public Object invoke(MethodInvocation invocation) throws Throwable
    {
        try
        {            
            return invocation.proceed();
        } 
        catch (Exception exp)
        {
            DatabasePageManagerCache.rollbackTransactions();
            throw exp;
        }
    }

}
